Enum ConditionType
#[repr(i32)]pub enum ConditionType {
Unspecified = 0,
StopLoss = 1,
TakeProfit = 2,
}Variants
Unspecified = 0
CONDITION_TYPE_UNSPECIFIED represents the default behavior where an order will be placed immediately on the orderbook.
StopLoss = 1
CONDITION_TYPE_STOP_LOSS represents a stop order. A stop order will trigger when the oracle price moves at or above the trigger price for buys, and at or below the trigger price for sells.
TakeProfit = 2
CONDITION_TYPE_TAKE_PROFIT represents a take profit order. A take profit order will trigger when the oracle price moves at or below the trigger price for buys and at or above the trigger price for sells.
Implementations
impl ConditionType
impl ConditionType
impl ConditionType
impl ConditionType
pub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
pub fn from_str_name(value: &str) -> Option<ConditionType>
pub fn from_str_name(value: &str) -> Option<ConditionType>
Creates an enum from field names used in the ProtoBuf definition.